@@ -167,13 +167,12 @@ class BaseModelAdmin:
         """
         raise NotImplementedError
 
-    async def save_model(self, obj: Any, payload: dict, add: bool = False) -> None:
+    async def save_model(self, id: str | None, payload: dict) -> Any | None:
         """This method is used to save orm/db model object.
 
-        :params obj: an orm/db model object.
+        :params id: an id of object.
         :params payload: a payload from request.
-        :params add: a flag for add or update object.
-        :return: None.
+        :return: A saved object or None.
         """
         raise NotImplementedError
 
@@ -212,6 +211,23 @@ class BaseModelAdmin:
         """
         raise NotImplementedError
 
+    def get_model_fields(self) -> OrderedDict[str, dict]:
+        """This method is used to get all orm/db model fields
+        with saving ordering (non relations, fk, o2o, m2m).
+
+        :return: An OrderedDict of model fields.
+        """
+        raise NotImplementedError
+
+    def get_form_widget(self, field_name: str) -> tuple[WidgetType, dict]:
+        """This method is used to get form item widget
+        for field from orm/db model.
+
+        :params field_name: a model field name.
+        :return: A tuple of widget type and widget props.
+        """
+        raise NotImplementedError
+
     async def get_export(
         self,
         export_format: ExportFormat | None,
@@ -245,23 +261,6 @@ class BaseModelAdmin:
             return output
         return None
 
-    def get_model_fields(self) -> OrderedDict[str, dict]:
-        """This method is used to get all orm/db model fields
-        with saving ordering (non relations, fk, o2o, m2m).
-
-        :return: An OrderedDict of model fields.
-        """
-        raise NotImplementedError
-
-    def get_form_widget(self, field_name: str) -> tuple[WidgetType, dict]:
-        """This method is used to get form item widget
-        for field from orm/db model.
-
-        :params field_name: a model field name.
-        :return: A tuple of widget type and widget props.
-        """
-        raise NotImplementedError
-
     def get_filter_widget(self, field_name: str) -> tuple[WidgetType, dict]:
         """This method is used to get filter widget for tabel columns
         for field from orm/db model from list_filter parameter.
